==> haskell-monad-unlift-0.2.0-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-FiFlHxTZn0P1T4Wt3hiE5L
key: monad-unlift-0.2.0-FiFlHxTZn0P1T4Wt3hiE5L
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: 3705b92da223cde4124e4058e6bc4e2d
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-FiFlHxTZn0P1T4Wt3hiE5L
depends:
    base-4.11.1.0 monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU
    transformers-0.5.5.0
    transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts
    constraints-0.10.1-LsiJjUfK3suAFcfwQSuJNF
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             monad-control-1.0.2.3-7JzgqOE5QdMK1n6qA1B9zU=69e6cbcc316152f03e15a8ee01a3a4a0
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-AexAWi6e5nx6jQ9Vfwnuts=429c07af1089832867529f5d7ce0e624
             constraints-0.10.1-LsiJjUfK3suAFcfwQSuJNF=0b98aa3109233d859b1cab45d350457c
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-unlift-0.2.0-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-unlift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-unlift
version: 0.2.0
id: monad-unlift-0.2.0-G6z2k4XfybD9imCt4ucQwf
key: monad-unlift-0.2.0-G6z2k4XfybD9imCt4ucQwf
license: MIT
copyright: FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/monad-unlift
synopsis: Typeclasses for representing monad transformer unlifting
description:
    See README.md
category: Control
abi: 313fc878b5457323a53115477e7679f9
exposed: True
exposed-modules:
    Control.Monad.Trans.Unlift
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-unlift-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-unlift-0.2.0
hs-libraries: HSmonad-unlift-0.2.0-G6z2k4XfybD9imCt4ucQwf
depends:
    base-4.11.1.0 monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI
    transformers-0.5.5.0
    transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ
    constraints-0.10.1-EfLG9Mns1yhDvwjl5KzwlL
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             monad-control-1.0.2.3-8qJgo7g8lzF2BtkxCSCnkI=20a8eb22fe1aed2b5899ee3d85a0cb2b
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-EvdLB4rIPwW4Mi0YtbCZsZ=9b46c0c542bc8ac21f832a06a7f8e9d2
             constraints-0.10.1-EfLG9Mns1yhDvwjl5KzwlL=5e7e8e915c1f5c731c96015239fc9ba2
haddock-interfaces: /usr/share/doc/haskell-monad-unlift/html/monad-unlift.haddock
haddock-html: /usr/share/doc/haskell-monad-unlift/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
